@@ -21,8 +21,7 @@ OPERATION_LIST = [
     "rss",
     "sum",
     "mean",
-    "integrate",
-    "overlay/filter",
+    "overlay",
 ]
 
 
@@ -81,7 +80,7 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
             if self.axis_name in fft_dict:
                 return fft_dict[self.axis_name] + action
 
-        elif action_type == "overlay/filter":
+        elif action_type == "overlay":
             indices = self.axis.get_values()
 
             action = "["
@@ -146,12 +145,12 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
         # Setting the label of the widget with the right name
         self.set_name(operation_name)
 
-        # Converting type of the operation if we have a slice or a overlay/filter
+        # Converting type of the operation if we have a slice or an overlay
         if operation_type == "single":
             operation_type = "slice"
 
         elif operation_type == "list":
-            operation_type = "overlay/filter"
+            operation_type = "overlay"
 
         # Setting operation combobox to the right operation
         self.c_operation.setCurrentIndex(self.c_operation.findText(operation_type))
@@ -241,6 +240,7 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
         if self.axis.is_components or self.axis.is_overlay:
             operation_list.remove("slice")
         else:
+            operation_list.remove("overlay")
             self.set_slider_floatedit()
 
         # Remove fft slice for non fft axes
@@ -286,18 +286,13 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
             self.slider.show()
             self.b_action.hide()
             self.refreshNeeded.emit()
-        # If the operation selected is overlay/filter then we show the related button
-        elif extraction_selected == "overlay/filter":
+        # If the operation selected is overlay then we show the related button
+        elif extraction_selected == "overlay":
             self.lf_value.hide()
             self.slider.hide()
             # self.b_action.show()
             # self.b_action.setText(extraction_selected)
             self.refreshNeeded.emit()
-
-        elif extraction_selected == "integrate":
-            self.lf_value.hide()
-            self.slider.hide()
-            self.b_action.hide()
         else:
             self.lf_value.hide()
             self.slider.hide()
